@@ -30,6 +30,8 @@ END
 
    SHOWING_FROM_TO => '%s from %s:%s..%s',
 
+   CURRENTLY_SHOWING => '(Currently showing %s)',
+
    INSTRUCTIONS      => 'Instructions',
 
    HIDE              => 'Hide',
@@ -104,8 +106,21 @@ END
     
    CLEAR_FAV     => 'Clear All Favorites',
 
-#############
+   ADDED_TO     => 'Add track to favorites',
 
+#############
+   
+   SNAPSHOT_FORM   => 'Snapshot Name',
+
+   CURRENT_SNAPSHOT => 'Current Snapshot:',
+
+   TIMESTAMP      => 'Snapshot Timestamp [GMT]',
+
+   SNAPSHOT_SELECT => 'Snapshots',
+
+   SAVE_SNAPSHOT   => 'Save Snapshot',
+
+   LOAD_SNAPSHOT   => 'Load Snapshot',
 
    SELECT_TRACKS   => 'Select Tracks',
 
@@ -145,7 +160,7 @@ END
 
    SUBTRACK_INSTRUCTIONS   => 'Select the tracks you wish to display. Sort the tracks by clicking on the column headings, or by clicking and dragging rows into position.',
 
-   SELECT_SUBTRACKS   => '%d of %d subtracks selected',
+   SELECT_SUBTRACKS   => 'showing %d/%d subtracks',
 
    EDIT       => 'Edit File...',
 
@@ -217,7 +232,9 @@ END
 
    REMOTE_TITLE => 'Add remote annotations',
 
-   IPAD_BALLOON => 'Tap features twice to see more details',
+   #ipad
+   IPAD_BALLOON => '\nTap feature again to see more details',
+   #
 
    REMOTE_URL   => 'Enter remote track URL',
 
@@ -235,6 +252,8 @@ END
 
    FEATURES_CLIPPED => 'Showing %s of %s features',
 
+   FEATURES_CLIPPED_MAX => 'Showing %s of >%s features',
+
    FILE_INFO    => 'Last modified %s.  Annotated landmarks: %s',
 
    FOOTER_1     => <<END,
@@ -388,7 +407,6 @@ END
 
  ADD_DESCRIPTION    => 'Click to add a description',
  ADD_TITLE          => 'Click to edit the title',
- EDIT_LABEL         => 'Click to view track. Shift or control-click to edit.',
  NO_DESCRIPTION     => 'No description',
 
  CONFIGURATION     => 'Configuration',
@@ -431,11 +449,16 @@ END
 
  SCALE_MAX        => 'Maximum scale value',
 
+ MIN              => 'Min',
+ MAX              => 'Max',
+
  SHOW_VARIANCE    => 'Show variance band',
 
- APPLY_CONFIG     => 'Apply this config when region >=',
+ APPLY_CONFIG     => 'Apply config when view between',
 
- SHOW_SUMMARY     => 'Show summary when region >=',
+ SHOW_SUMMARY     => 'Show summary when region >',
+
+ FEATURE_SUMMARY     => 'Feature Density Summary',
 
  LINEWIDTH        => 'Line width',
 
@@ -461,7 +484,7 @@ END
 
  CONFIGURE_THIS_TRACK   => '<b>Configure this track</b>',
 
- DOWNLOAD_THIS_TRACK   => '<b>Download this track test</b>',
+ DOWNLOAD_THIS_TRACK   => '<b>Download this track</b>',
 
  ABOUT_THIS_TRACK   => '<b>About this track</b>',
 
@@ -660,7 +683,7 @@ END
                                 '<br><br>To complete the account creation process and to log into your %s ' .
                                 'account, please type in your username and click the "Continue" button below.',
    MUST_TYPE_USERNAME        => 'You must type in your username to continue.',
-   INCORRECT_LINK            => 'The confirmation code provided is either incorrect or expired.<br> Please click continue to exit.',
+   INCORRECT_LINK            => 'The link provided is either incorrect or expired.<br> Please click continue to exit.',
    PENDING                   => 'pending',
    
    WELCOME                   => 'Welcome, %s',
