@@ -763,7 +763,6 @@ sub invert_types {
 	    $length = $2;
 	}
 
-	#  sigh... reverse multiplier effect for semantic zooming....
 	my $section =  $self->get_section_from_label($label) || 'detail';
 	$length    *= $multiplier if $section eq 'detail';
 
@@ -1343,7 +1342,24 @@ sub get_section_from_label {
         return 'region';
     }
     return 'detail'
+}
 
+=head2 $boolean = $source->use_inline_imagemap($label=>$length)
+
+Given a track label and length (for semantic zooming) return true
+if we should generate an inline clickable imagemap vs one in which
+the actions are generated by Ajax callbacks
+
+=cut
+
+sub use_inline_imagemap {
+    my $self = shift;
+    my ($label,$length) = @_;
+    my $inline = $self->semantic_fallback_setting($label=>'inline imagemaps',$length) 
+	       ||$self->semantic_fallback_setting($label=>'inline imagemap', $length);
+    return $inline if defined $inline;
+    my $db = $self->open_database($label,$length) or return 1;
+    return !$db->can('get_feature_by_id');
 }
 
 1;
