@@ -398,7 +398,7 @@ sub _search_features_locally {
 
     for my $dbid (@dbids) {
 	my $opts = $self->source->search_options($dbid);
-	next if $opts =~ /none/i;
+	next if $opts =~ /none/i && $args->{-name} !~ /^id:/;
 	warn "searching in ",$dbid if DEBUG;
 	my $db = $self->source->open_database($dbid);
 	next if $seenit{$db}++;
