@@ -264,6 +264,7 @@ sub _dump_gff3 {
 sub dump_sam {
     my $self = shift;
     my ($db,$segment,$types,$label) = @_;
+
     my @args = $segment ? (-seq_id => $segment->seq_id,
 			   -start  => $segment->start,
 			   -end    => $segment->end)
@@ -275,13 +276,15 @@ sub dump_sam {
     my $header = $db->header;
 
     my $prefix = $self->add_prefix;
-    my $seq_id  = $segment->seq_id;
-    $seq_id     = "$prefix$seq_id" if $prefix;
 
     print $header->text;
     print "\@CO\t$key\n";
     print "\@CO\tGenerated by GBrowse from ",$self->origin($label),"\n";
-    print "\@CO\tSequence-region ",$seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
+    if ($segment) {
+	my $seq_id  = $segment->seq_id;
+	$seq_id     = "$prefix$seq_id" if $prefix;
+	print "\@CO\tSequence-region ",$seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
+    }
 
     # there are problems with the filehandle-based conversion of 
     # BAM to TAM because the low-level functions write to STDOUT directly
